Module: tools
Branch: master
Commit: 34b71eecf88d54d4cf86d56dc6c53a780b259a15
URL: https://gitlab.winehq.org/winehq/tools/-/commit/34b71eecf88d54d4cf86d56dc6c…
Author: Francois Gouget <fgouget(a)codeweavers.com>
Date: Tue Oct 25 15:04:24 2022 +0200
testbot/LogUtils: Remove the unused $LogInfo->{Failures} field.
It was essentially redundant with the ErrCount field anyway, except
that the latter includes the flaky failures. Also this field name
could cause confusion with the per-MsgGroup Failures field used to
track known failures.
---
testbot/lib/WineTestBot/LogUtils.pm | 8 --------
1 file changed, 8 deletions(-)
diff --git a/testbot/lib/WineTestBot/LogUtils.pm b/testbot/lib/WineTestBot/LogUtils.pm
index a9c893a3..05af274c 100644
--- a/testbot/lib/WineTestBot/LogUtils.pm
+++ b/testbot/lib/WineTestBot/LogUtils.pm
@@ -382,7 +382,6 @@ sub _AddExtra($$;$)
$Error = "$Cur->{Dll}:$Cur->{Unit} $Error" if (defined $Cur);
push @{$LogInfo->{Extra}}, $Error;
- $LogInfo->{Failures}++;
}
sub _CheckUnit($$$$)
@@ -472,8 +471,6 @@ sub _CloseTestUnit($$$)
}
}
}
-
- $LogInfo->{Failures} += $Cur->{LineFailures};
}
sub _AddReportError($$$$)
@@ -516,9 +513,6 @@ The number of test units.
=item TimeoutCount
The number of test units that timed out.
-=item Failures
-The number of failed tests.
-
=item ErrCount, ErrGroupNames, ErrGroups, BadLog
See ParseTaskLog() for details.
@@ -539,7 +533,6 @@ sub ParseWineTestReport($$$)
TestUnitCount => 0,
TimeoutCount => 0,
- Failures => undef,
ErrGroupNames => [],
ErrGroups => {},
@@ -750,7 +743,6 @@ sub ParseWineTestReport($$$)
{
# The done line will already be shown as a timeout (see JobDetails)
# so record the failure but don't add an error message.
- $LogInfo->{Failures}++;
$Cur->{IsBroken} = 1;
$LogInfo->{TimeoutCount}++;
_AddReportError($LogInfo, $Cur, $LineNo, $&);
Module: tools
Branch: master
Commit: 818aebb2e41bbcec3cacd0723b59a9e867320732
URL: https://gitlab.winehq.org/winehq/tools/-/commit/818aebb2e41bbcec3cacd0723b5…
Author: Francois Gouget <fgouget(a)codeweavers.com>
Date: Mon Oct 24 19:00:59 2022 +0200
testbot: Fix the tasks failure count.
TestFailures is supposed to count all failures, including the
preexisting (aka old) and flaky ones. Checking whether any of these
failures is new must be done by analyzing the content of the task's
.errors files.
---
testbot/bin/WineRunTask.pl | 4 ++--
testbot/bin/WineRunWineTest.pl | 4 ++--
2 files changed, 4 insertions(+), 4 deletions(-)
diff --git a/testbot/bin/WineRunTask.pl b/testbot/bin/WineRunTask.pl
index 0641bb54..67ba3288 100755
--- a/testbot/bin/WineRunTask.pl
+++ b/testbot/bin/WineRunTask.pl
@@ -562,8 +562,8 @@ if ($TA->GetFile($RptFileName, "$TaskDir/$RptFileName"))
my $ErrMessages = SnapshotLatestReport($Task, $RptFileName);
LogTaskError("$_\n") for (@$ErrMessages);
- # $LogInfo->{Failures} can legitimately be undefined in case of a timeout
- $TaskFailures += $LogInfo->{Failures} || 0;
+ # $LogInfo->{ErrCount} can legitimately be undefined in case of a timeout
+ $TaskFailures += $LogInfo->{ErrCount} || 0;
my $LogErrMsg = CreateLogErrorsCache($LogInfo, $Task);
LogTaskError("$LogErrMsg\n") if (defined $LogErrMsg);
}
diff --git a/testbot/bin/WineRunWineTest.pl b/testbot/bin/WineRunWineTest.pl
index 62a7fc5b..d0e30d1c 100755
--- a/testbot/bin/WineRunWineTest.pl
+++ b/testbot/bin/WineRunWineTest.pl
@@ -578,8 +578,8 @@ foreach my $RptFileName (@$ReportNames)
my $ErrMessages = SnapshotLatestReport($Task, $RptFileName);
LogTaskError("$_\n") for (@$ErrMessages);
- # $LogInfo->{Failures} can legitimately be undefined in case of a timeout
- $TaskFailures += $LogInfo->{Failures} || 0;
+ # $LogInfo->{ErrCount} can legitimately be undefined in case of a timeout
+ $TaskFailures += $LogInfo->{ErrCount} || 0;
my $LogErrMsg = CreateLogErrorsCache($LogInfo, $Task);
LogTaskError("$LogErrMsg\n") if (defined $LogErrMsg);
}